==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/uls_update_batch.sh <==
#!/bin/bash
#
# uls_update_batch.sh
#
# ULS-Software updaten
#
# Aufruf: uls_update_batch.sh [-h <old-version>] [-v <old-version>] [-C] <mysqldefaultsfile>
#         -v <old-version>    Die Skripts zum Update von der
#                             Version <old-version> ausgefuehrt,
#                             auch wenn die Datenbank schon eine
#                             hoehere Version hat.
#         -h <old-version>    Es werden nur die Hilfetexte der Version <old-version>
#                             neu eingelesen
#         -C                  <mysqldefaultsfile> wird nach Verarbeitung geloescht
#
######################################################################################
#
ULSDIR=`./get_uls_dir.sh`
if [[ -z "$ULSDIR" ]]
 then
  echo "ULS-Installation not found!"
  exit 1
fi
#
unset OLDVERSION ONLYHELP CLEANFILE
#
while getopts Cv:h: op
 do
  case "$op" in
   C) CLEANFILE=1;;
   v) OLDVERSION=$OPTARG;;
   h) ONLYHELP=1
      OLDVERSION=$OPTARG;;
   *) echo "usage: $0 [-h <old-version>|-v <old-version>] <mysqldefaultsfile>"
      exit 1;;
  esac
done
shift $(( $OPTIND -1))
#
if [[ $# -ne 1 ]]
 then
  echo "usage: $0 [-h <old-version>|-v <old-version>] <mysqldefaultsfile>"
  exit 1
fi
#
#
MYSQLDEFAULTS="$1"
#
MYSQLP="mysql --defaults-extra-file=$MYSQLDEFAULTS -nvvv logging"
MYSQLPFORCE="mysql --defaults-extra-file=$MYSQLDEFAULTS --force -nvvv logging"
MYSQLO="mysql --defaults-extra-file=$MYSQLDEFAULTS -B -N logging"
MYSQLC="mysql --defaults-extra-file=$MYSQLDEFAULTS logging"
MYSQLCT="mysql --defaults-extra-file=$MYSQLDEFAULTS loggingtmp"
#
#
cd `dirname $0`
#
performhelp()
{ if [[ -f von_$1/helppages.sql ]]
   then
    echo "Hilfeseiten von von_$1/helppages.sql einlesen"
    $MYSQLCT <von_$1/helppages.sql
    $MYSQLC <<EOF
delete hilfetexte from hilfetexte join loggingtmp.hilfetexte as tht using (lang,name);
insert into hilfetexte (lang, name, text, includes, helpset)
  select lang, name, text, includes, helpset
  from loggingtmp.hilfetexte;
  drop table loggingtmp.hilfetexte;
EOF
  elif [[ -d von_$1/Hilfetexte ]]
   then
    for p in `ls von_$1/Hilfetexte/*.html 2>/dev/null`
     do
      NAME=`basename $p .html`
      $MYSQLC -e "delete from hilfetexte where name='$NAME'"
      $MYSQLC -e "insert into hilfetexte set name='$NAME', helpset='ConfigHints', text='`sed -f hilfetexte.sed $p | awk -f hilfetexte.awk`'"
    done
    for p in `ls von_$1/Hilfetexte/*/*.html 2>/dev/null`
     do
      NAME=`basename $p .html`
      HLANG=`echo $p | awk -F '/' '{print $(NF-1)}'`
      $MYSQLC -e "delete from hilfetexte where name='$NAME' and lang='$HLANG'"
      $MYSQLC -e "insert into hilfetexte set name='$NAME', lang='$HLANG', helpset='ConfigHints', text='`sed -f hilfetexte.sed $p | awk -f hilfetexte.awk`'"
    done
  fi
}
#
if [[ -n "$ONLYHELP" ]]
 then
  performhelp $OLDVERSION
  exit 0
fi
#
if [[ -z "$OLDVERSION" ]]
 then
  VERSIONS="`ls -d von_* | sed 's/von_//g'`"
else
  VERSIONS="$OLDVERSION"
fi
#
for v in $VERSIONS
 do
  DBCUR=`$MYSQLO -e "select wert from systemvars where name='dbversion'"`
  if [[ -z "$DBCUR" ]]
   then
    echo "Die aktuelle Version der Datenbank kann nicht bestimmt werden."
    echo "Die Verarbeitung wird abgebrochen."
    echo "Das Datenbank-Kennwort ist wahrscheinlich falsch."
    exit 1
  fi
  if [[ "$DBCUR" = "$v" || "$OLDVERSION" = "$v" ]]
   then
    date
    if [[ -s von_$v/update_check.sh ]]
     then
      echo "Start von_$v/update_check.sh"
      bash von_$v/update_check.sh "$MYSQLDEFAULTS"
      RET=$?
      [[ $RET != 0 ]] && echo "Update Check Fehlgeschlagen, Installation wird abgebrochen!" && exit 1
      echo "done von_$v/update_check.sh"
    fi
    date
    if [[ -s von_$v/preinst.sh ]]
     then
      echo "Preinstall Script"
      bash von_$v/preinst.sh "$ULSDIR"
    fi
    if [[ -d von_$v/src ]]
     then
      echo "Neue Binaries kompilieren"
      for s in von_$v/src/*
       do
        if [[ -d "$s" ]]
         then
          (cd "$s"; make)
          RET=$?
          [[ $RET != 0 ]] && echo "Fehler beim Kompilieren, Installation wird abgebrochen!" && exit 1
        fi
      done
      [[ -d $ULSDIR/wwwbin ]] || mkdir -p $ULSDIR/wwwbin
      cp -a von_$v/src $ULSDIR/wwwbin
    fi
    date
    echo "Datenbankupdate ab Version $v"
    if [[ -d von_$v/sql_pre ]]
     then
      for p in `ls von_$v/sql_pre/*.sql 2>/dev/null`
       do
        date
        echo "Pre-Script `basename $p`"
        (echo "set sql_mode = '';" ; cat $p ) | $MYSQLP
        echo "Ende Pre-Script `basename $p`"
      done
    fi
    date
    if [[ -d von_$v/src ]]
     then
      echo "Neue Binaries installieren"
      for s in von_$v/src/*
       do
        [[ -d "$s" ]] && (cd "$s"; make install)
      done
    fi
    date
    if [[ -s von_$v/update.sh ]]
     then
      echo "System-Update-Script"
      bash von_$v/update.sh "$ULSDIR"
    fi
    date
    echo "DB-Update-Script"
    (echo "set sql_mode = '';" ; cat von_$v/db_update.sql) | $MYSQLPFORCE
    echo "Ende DB-Update-Script"
    echo
    if [[ -d von_$v/sql ]]
     then
      for p in `ls von_$v/sql/*.sql 2>/dev/null`
       do
        date
        echo "SQL-Script `basename $p`"
        (echo "set sql_mode = '';" ; cat $p ) | $MYSQLC
        echo "Ende SQL-Script `basename $p`"
      done
    fi
    if [[ -s von_$v/uls_soft.tgz ]]
     then
      date
      echo "Uls-Software updaten:"
      tar xfz von_$v/uls_soft.tgz -C "`dirname $ULSDIR`"
      echo "Uls-Software entpackt."
      echo
    fi
    if [[ -s von_$v/postinst.sh ]]
     then
      bash von_$v/postinst.sh "$ULSDIR" "$MYSQLDEFAULTS"
    fi
    echo
    if [[ -d von_$v/sql_post ]]
     then
      for p in `ls von_$v/sql_post/*.sql 2>/dev/null`
       do
        date
        echo "Post-Script `basename $p`"
        (echo "set sql_mode = '';" ; cat $p ) | $MYSQLP
        echo "Ende Post-Script `basename $p`"
      done
    fi
    performhelp $v
    echo "Neue Datenbankversion: "`$MYSQLO -e "select wert from systemvars where name='dbversion'"`
    echo
  fi
done
#
if [[ -n "$CLEANFILE" ]]
 then
  rm $MYSQLDEFAULTS
fi
#
date
echo "Das Update ist durchgelaufen"

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/uls_update_batch.sh <==
#!/bin/bash
#
# uls_update_batch.sh
#
# ULS-Software updaten
#
# Aufruf: uls_update_batch.sh [-h <old-version>] [-v <old-version>] [-C] <mysqldefaultsfile>
#         -v <old-version>    Die Skripts zum Update von der
#                             Version <old-version> ausgefuehrt,
#                             auch wenn die Datenbank schon eine
#                             hoehere Version hat.
#         -h <old-version>    Es werden nur die Hilfetexte der Version <old-version>
#                             neu eingelesen
#         -C                  <mysqldefaultsfile> wird nach Verarbeitung geloescht
#
######################################################################################
#
ULSDIR=`./get_uls_dir.sh`
if [[ -z "$ULSDIR" ]]
 then
  echo "ULS-Installation not found!"
  exit 1
fi
#
unset OLDVERSION ONLYHELP CLEANFILE
#
while getopts Cv:h: op
 do
  case "$op" in
   C) CLEANFILE=1;;
   v) OLDVERSION=$OPTARG;;
   h) ONLYHELP=1
      OLDVERSION=$OPTARG;;
   *) echo "usage: $0 [-h <old-version>|-v <old-version>] <mysqldefaultsfile>"
      exit 1;;
  esac
done
shift $(( $OPTIND -1))
#
if [[ $# -ne 1 ]]
 then
  echo "usage: $0 [-h <old-version>|-v <old-version>] <mysqldefaultsfile>"
  exit 1
fi
#
#
MYSQLDEFAULTS="$1"
#
MYSQLP="mysql --defaults-extra-file=$MYSQLDEFAULTS -nvvv logging"
MYSQLPFORCE="mysql --defaults-extra-file=$MYSQLDEFAULTS --force -nvvv logging"
MYSQLO="mysql --defaults-extra-file=$MYSQLDEFAULTS -B -N logging"
MYSQLC="mysql --defaults-extra-file=$MYSQLDEFAULTS logging"
MYSQLCT="mysql --defaults-extra-file=$MYSQLDEFAULTS loggingtmp"
#
#
cd `dirname $0`
#
performhelp()
{ if [[ -f von_$1/helppages.sql ]]
   then
    echo "Hilfeseiten von von_$1/helppages.sql einlesen"
    $MYSQLCT <von_$1/helppages.sql
    $MYSQLC <<EOF
delete hilfetexte from hilfetexte join loggingtmp.hilfetexte as tht using (lang,name);
insert into hilfetexte (lang, name, text, includes, helpset)
  select lang, name, text, includes, helpset
  from loggingtmp.hilfetexte;
  drop table loggingtmp.hilfetexte;
EOF
  elif [[ -d von_$1/Hilfetexte ]]
   then
    for p in `ls von_$1/Hilfetexte/*.html 2>/dev/null`
     do
      NAME=`basename $p .html`
      $MYSQLC -e "delete from hilfetexte where name='$NAME'"
      $MYSQLC -e "insert into hilfetexte set name='$NAME', helpset='ConfigHints', text='`sed -f hilfetexte.sed $p | awk -f hilfetexte.awk`'"
    done
    for p in `ls von_$1/Hilfetexte/*/*.html 2>/dev/null`
     do
      NAME=`basename $p .html`
      HLANG=`echo $p | awk -F '/' '{print $(NF-1)}'`
      $MYSQLC -e "delete from hilfetexte where name='$NAME' and lang='$HLANG'"
      $MYSQLC -e "insert into hilfetexte set name='$NAME', lang='$HLANG', helpset='ConfigHints', text='`sed -f hilfetexte.sed $p | awk -f hilfetexte.awk`'"
    done
  fi
}
#
if [[ -n "$ONLYHELP" ]]
 then
  performhelp $OLDVERSION
  exit 0
fi
#
if [[ -z "$OLDVERSION" ]]
 then
  VERSIONS="`ls -d von_* | sed 's/von_//g'`"
else
  VERSIONS="$OLDVERSION"
fi
#
for v in $VERSIONS
 do
  DBCUR=`$MYSQLO -e "select wert from systemvars where name='dbversion'"`
  if [[ -z "$DBCUR" ]]
   then
    echo "Die aktuelle Version der Datenbank kann nicht bestimmt werden."
    echo "Die Verarbeitung wird abgebrochen."
    echo "Das Datenbank-Kennwort ist wahrscheinlich falsch."
    exit 1
  fi
  if [[ "$DBCUR" = "$v" || "$OLDVERSION" = "$v" ]]
   then
    date
    if [[ -s von_$v/update_check.sh ]]
     then
      echo "Start von_$v/update_check.sh"
      bash von_$v/update_check.sh "$MYSQLDEFAULTS"
      RET=$?
      [[ $RET != 0 ]] && echo "Update Check Fehlgeschlagen, Installation wird abgebrochen!" && exit 1
      echo "done von_$v/update_check.sh"
    fi
    date
    if [[ -s von_$v/preinst.sh ]]
     then
      echo "Preinstall Script"
      bash von_$v/preinst.sh "$ULSDIR"
    fi
    if [[ -d von_$v/src ]]
     then
      echo "Neue Binaries kompilieren"
      for s in von_$v/src/*
       do
        if [[ -d "$s" ]]
         then
          (cd "$s"; make)
          RET=$?
          [[ $RET != 0 ]] && echo "Fehler beim Kompilieren, Installation wird abgebrochen!" && exit 1
        fi
      done
      [[ -d $ULSDIR/wwwbin ]] || mkdir -p $ULSDIR/wwwbin
      cp -a von_$v/src $ULSDIR/wwwbin
    fi
    date
    echo "Datenbankupdate ab Version $v"
    if [[ -d von_$v/sql_pre ]]
     then
      for p in `ls von_$v/sql_pre/*.sql 2>/dev/null`
       do
        date
        echo "Pre-Script `basename $p`"
        (echo "set sql_mode = 'NO_AUTO_CREATE_USER';" ; cat $p ) | $MYSQLP
        echo "Ende Pre-Script `basename $p`"
      done
    fi
    date
    if [[ -d von_$v/src ]]
     then
      echo "Neue Binaries installieren"
      for s in von_$v/src/*
       do
        [[ -d "$s" ]] && (cd "$s"; make install)
      done
    fi
    date
    if [[ -s von_$v/update.sh ]]
     then
      echo "System-Update-Script"
      bash von_$v/update.sh "$ULSDIR"
    fi
    date
    echo "DB-Update-Script"
    (echo "set sql_mode = 'NO_AUTO_CREATE_USER';" ; cat von_$v/db_update.sql) | $MYSQLPFORCE
    echo "Ende DB-Update-Script"
    echo
    if [[ -d von_$v/sql ]]
     then
      for p in `ls von_$v/sql/*.sql 2>/dev/null`
       do
        date
        echo "SQL-Script `basename $p`"
        (echo "set sql_mode = 'NO_AUTO_CREATE_USER';" ; cat $p ) | $MYSQLC
        echo "Ende SQL-Script `basename $p`"
      done
    fi
    if [[ -s von_$v/uls_soft.tgz ]]
     then
      date
      echo "Uls-Software updaten:"
      tar xfz von_$v/uls_soft.tgz -C "`dirname $ULSDIR`"
      echo "Uls-Software entpackt."
      echo
    fi
    if [[ -s von_$v/postinst.sh ]]
     then
      bash von_$v/postinst.sh "$ULSDIR" "$MYSQLDEFAULTS"
    fi
    echo
    if [[ -d von_$v/sql_post ]]
     then
      for p in `ls von_$v/sql_post/*.sql 2>/dev/null`
       do
        date
        echo "Post-Script `basename $p`"
        (echo "set sql_mode = 'NO_AUTO_CREATE_USER';" ; cat $p ) | $MYSQLP
        echo "Ende Post-Script `basename $p`"
      done
    fi
    performhelp $v
    echo "Neue Datenbankversion: "`$MYSQLO -e "select wert from systemvars where name='dbversion'"`
    echo
  fi
done
#
if [[ -n "$CLEANFILE" ]]
 then
  rm $MYSQLDEFAULTS
fi
#
date
echo "Das Update ist durchgelaufen"
